@@ -141,57 +141,37 @@ static void set_picking_scale_gravity(TangleActor* actor, ClutterGravity gravity
 static gboolean handle_queued_events(TangleActor* actor);
 static void unset_transition_scale_children(TangleActor* actor);
 static void on_hiding_animation_completed(TangleActor* actor);
+static void setup_animation_valist(ClutterAnimation* animation, TangleActor* actor, const gchar* first_property_name, va_list args);
 
 static guint signals[LAST_SIGNAL] = { 0 };
 static ClutterScriptableIface* parent_scriptable_iface = NULL;
 
 ClutterAnimation* tangle_actor_animate(TangleActor* actor, gulong mode, guint duration, const gchar* first_property_name, ...) {
 	ClutterAnimation* animation;
-	GObjectClass *klass;
 	va_list args;
-	const gchar* property_name;
 	
 	animation = clutter_animation_new();
-	clutter_animation_set_object(animation, G_OBJECT(actor));
 	clutter_animation_set_mode(animation, mode);
 	clutter_animation_set_duration(animation, duration);
-	g_signal_connect(animation, "completed", G_CALLBACK(on_animation_completed), actor);
-
-	klass = G_OBJECT_GET_CLASS(actor);
 
 	va_start(args, first_property_name);
-	for (property_name = first_property_name; property_name; property_name = va_arg(args, gchar*)) {
-		GParamSpec *param_spec;
-		GValue value = { 0 };
-		gchar* error;
-		
-		if ((param_spec = g_object_class_find_property(klass, property_name))) {
-			g_value_init(&value, G_PARAM_SPEC_VALUE_TYPE(param_spec));
-			error = NULL;
-			G_VALUE_COLLECT(&value, args, 0, &error);
-			if (!error) {
-				ClutterAnimation* existing_animation;
-				
-				if ((existing_animation = g_hash_table_lookup(actor->priv->animations, property_name))) {
-					clutter_animation_unbind_property(existing_animation, property_name);
-					g_hash_table_remove(actor->priv->animations, property_name);
-				}
-				clutter_animation_bind(animation, property_name, &value);
-				g_hash_table_insert(actor->priv->animations, g_strdup(property_name), g_object_ref(animation)); // gobject_ref_sink does not work with 0.9.2!
-			} else {
-				g_warning("%s: %s", G_STRLOC, error);
-				g_free(error);
-				break;
-			}
-			g_value_unset(&value);
-		} else {
-			g_warning ("Cannot bind property '%s'.", property_name);
-			break;
-		}
-	}
+	setup_animation_valist(animation, actor, first_property_name, args);
 	va_end(args);
 
-	clutter_timeline_start(clutter_animation_get_timeline(animation));
+	return animation;
+}
+
+ClutterAnimation* tangle_actor_animate_with_timeline(TangleActor* actor, gulong mode, ClutterTimeline* timeline, const gchar* first_property_name, ...) {
+	ClutterAnimation* animation;
+	va_list args;
+	
+	animation = clutter_animation_new();
+	clutter_animation_set_mode(animation, mode);
+	clutter_animation_set_timeline(animation, timeline);
+
+	va_start(args, first_property_name);
+	setup_animation_valist(animation, actor, first_property_name, args);
+	va_end(args);
 
 	return animation;
 }
@@ -1828,3 +1808,45 @@ static void on_hiding_animation_completed(TangleActor* actor) {
 	}
 	actor->priv->hide_all = FALSE;
 }
+
+static void setup_animation_valist(ClutterAnimation* animation, TangleActor* actor, const gchar* first_property_name, va_list args) {
+	GObjectClass *klass;
+	const gchar* property_name;
+
+	clutter_animation_set_object(animation, G_OBJECT(actor));
+	g_signal_connect(animation, "completed", G_CALLBACK(on_animation_completed), G_OBJECT(actor));
+
+	klass = G_OBJECT_GET_CLASS(actor);
+
+	for (property_name = first_property_name; property_name; property_name = va_arg(args, gchar*)) {
+		GParamSpec *param_spec;
+		GValue value = { 0 };
+		gchar* error;
+		
+		if ((param_spec = g_object_class_find_property(klass, property_name))) {
+			g_value_init(&value, G_PARAM_SPEC_VALUE_TYPE(param_spec));
+			error = NULL;
+			G_VALUE_COLLECT(&value, args, 0, &error);
+			if (!error) {
+				ClutterAnimation* existing_animation;
+				
+				if ((existing_animation = g_hash_table_lookup(actor->priv->animations, property_name))) {
+					clutter_animation_unbind_property(existing_animation, property_name);
+					g_hash_table_remove(actor->priv->animations, property_name);
+				}
+				clutter_animation_bind(animation, property_name, &value);
+				g_hash_table_insert(actor->priv->animations, g_strdup(property_name), g_object_ref(animation)); // gobject_ref_sink does not work with 0.9.2!
+			} else {
+				g_warning("%s: %s", G_STRLOC, error);
+				g_free(error);
+				break;
+			}
+			g_value_unset(&value);
+		} else {
+			g_warning ("Cannot bind property '%s'.", property_name);
+			break;
+		}
+	}
+
+	clutter_timeline_start(clutter_animation_get_timeline(animation));
+}
