@@ -20,8 +20,11 @@ G_DEFINE_TYPE(TangleButton, tangle_button, TANGLE_TYPE_WIDGET);
 
 enum {
 	PROP_0,
+	PROP_BUTTON_MODE,
 	PROP_NORMAL_BACKGROUND_ACTOR,
 	PROP_INTERACTIVE_BACKGROUND_ACTOR,
+	PROP_SELECTED_BACKGROUND_ACTOR,
+	PROP_SELECTED,
 	PROP_CLICKED_ACTION
 };
 
@@ -31,12 +34,23 @@ enum {
 };
 
 struct _TangleButtonPrivate {
+	TangleButtonMode mode;
 	ClutterActor* normal_background_actor;
 	ClutterActor* interactive_background_actor;
+	ClutterActor* selected_background_actor;
 	TangleAction* clicked_action;
+
 	guint button_release_event_handler_id;
+
 	guint active : 1;
 	guint inside : 1;
+	guint selected : 1;
+};
+
+static const GEnumValue button_mode_values[] = {
+	{ TANGLE_BUTTON_CLICKABLE, "TANGLE_BUTTON_CLICKABLE", "clickable" },
+	{ TANGLE_BUTTON_SELECTABLE, "TANGLE_BUTTON_SELECTABLE", "selectable" },
+	{ 0, NULL, NULL }
 };
 
 static void begin_interacting(TangleButton* button);
@@ -44,6 +58,16 @@ static void end_interacting(TangleButton* button);
 
 static guint signals[LAST_SIGNAL];
 
+GType tangle_button_mode_get_type(void) {
+	static GType type = 0;
+	
+	if (!type) {
+		type = g_enum_register_static("TangleButtonMode", button_mode_values);
+	}
+	
+	return type;
+}
+
 ClutterActor* tangle_button_new(void) {
 
 	return CLUTTER_ACTOR(g_object_new(TANGLE_TYPE_BUTTON, NULL));
@@ -51,12 +75,42 @@ ClutterActor* tangle_button_new(void) {
 
 ClutterActor* tangle_button_new_with_background_actor(ClutterActor* normal_background_actor) {
 
-	return CLUTTER_ACTOR(g_object_new(TANGLE_TYPE_BUTTON, "normal-background-actor", normal_background_actor, "prefer-background-size", TRUE, NULL));
+	return CLUTTER_ACTOR(g_object_new(TANGLE_TYPE_BUTTON, "normal-background-actor", normal_background_actor, NULL));
 }
 
 ClutterActor* tangle_button_new_with_background_actors(ClutterActor* normal_background_actor, ClutterActor* interactive_background_actor) {
 
-	return CLUTTER_ACTOR(g_object_new(TANGLE_TYPE_BUTTON, "normal-background-actor", normal_background_actor, "interactive-background-actor", interactive_background_actor, "prefer-background-size", TRUE, NULL));
+	return CLUTTER_ACTOR(g_object_new(TANGLE_TYPE_BUTTON, "normal-background-actor", normal_background_actor, "interactive-background-actor", interactive_background_actor, NULL));
+}
+
+ClutterActor* tangle_button_new_selectable(void) {
+
+	return CLUTTER_ACTOR(g_object_new(TANGLE_TYPE_BUTTON, "button-mode", TANGLE_BUTTON_SELECTABLE, NULL));
+}
+
+ClutterActor* tangle_button_new_selectable_with_background_actor(ClutterActor* normal_background_actor) {
+
+	return CLUTTER_ACTOR(g_object_new(TANGLE_TYPE_BUTTON, "button-mode", TANGLE_BUTTON_SELECTABLE, "normal-background-actor", normal_background_actor, "prefer-background-size", TRUE, NULL));
+}
+
+ClutterActor* tangle_button_new_selectable_with_background_actors(ClutterActor* normal_background_actor, ClutterActor* interactive_background_actor, ClutterActor* selected_background_actor) {
+
+	return CLUTTER_ACTOR(g_object_new(TANGLE_TYPE_BUTTON, "button-mode", TANGLE_BUTTON_SELECTABLE, "normal-background-actor", normal_background_actor, "interactive-background-actor", interactive_background_actor, "selected-background-actor", selected_background_actor, NULL));
+}
+
+TangleButtonMode tangle_button_get_mode(TangleButton* button) {
+
+	return button->priv->mode;
+}
+
+void tangle_button_set_mode(TangleButton* button, TangleButtonMode mode) {
+	g_return_if_fail(mode >= TANGLE_BUTTON_CLICKABLE && mode <= TANGLE_BUTTON_SELECTABLE);
+	
+	if (button->priv->mode != mode) {
+		button->priv->mode = mode;
+		clutter_actor_queue_redraw(CLUTTER_ACTOR(button));
+		g_object_notify(G_OBJECT(button), "button-mode");
+	}
 }
 
 ClutterActor* tangle_button_get_normal_background_actor(TangleButton* button) {
@@ -65,17 +119,6 @@ ClutterActor* tangle_button_get_normal_background_actor(TangleButton* button) {
 	return button->priv->normal_background_actor;
 }
 
-ClutterActor* tangle_button_get_interactive_background_actor(TangleButton* button) {
-	g_return_val_if_fail(TANGLE_IS_BUTTON(button), NULL);
-
-	return button->priv->interactive_background_actor;
-}
-
-TangleAction* tangle_button_get_clicked_action(TangleButton* button) {
-
-	return button->priv->clicked_action;
-}
-
 void tangle_button_set_normal_background_actor(TangleButton* button, ClutterActor* actor) {
 	g_return_if_fail(TANGLE_IS_BUTTON(button));
         
@@ -92,6 +135,12 @@ void tangle_button_set_normal_background_actor(TangleButton* button, ClutterActo
 	}
 }
 
+ClutterActor* tangle_button_get_interactive_background_actor(TangleButton* button) {
+	g_return_val_if_fail(TANGLE_IS_BUTTON(button), NULL);
+
+	return button->priv->interactive_background_actor;
+}
+
 void tangle_button_set_interactive_background_actor(TangleButton* button, ClutterActor* actor) {
 	gboolean had_interactive_background_actor = FALSE;
 	
@@ -115,13 +164,53 @@ void tangle_button_set_interactive_background_actor(TangleButton* button, Clutte
 	}
 }
 
-void tangle_button_set_clicked_action(TangleButton* button, TangleAction* action) {
-	if (button->priv->clicked_action) {
-		g_object_unref(button->priv->clicked_action);
+ClutterActor* tangle_button_get_selected_background_actor(TangleButton* button) {
+	g_return_val_if_fail(TANGLE_IS_BUTTON(button), NULL);
+
+	return button->priv->selected_background_actor;
+}
+
+void tangle_button_set_selected_background_actor(TangleButton* button, ClutterActor* actor) {
+	gboolean had_selected_background_actor = FALSE;
+	
+	g_return_if_fail(TANGLE_IS_BUTTON(button));
+
+	if (button->priv->selected_background_actor != actor) {
+		if (button->priv->selected_background_actor) {
+			g_object_unref(button->priv->selected_background_actor);
+			had_selected_background_actor = TRUE;
+		}
+		button->priv->selected_background_actor = actor;
+		g_object_ref_sink(button->priv->selected_background_actor);
+
+		if (button->priv->selected) {
+			if (button->priv->selected_background_actor) {
+				tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->selected_background_actor);
+			} else if (had_selected_background_actor) {
+				tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
+			}
+		}
+	}
+}
+
+gboolean tangle_button_get_selected(TangleButton* button) {
+	gboolean selected = FALSE;
+	
+	if (button->priv->mode == TANGLE_BUTTON_SELECTABLE) {
+		selected = button->priv->selected;
+	}
+	
+	return selected;
+}
+	
+void tangle_button_set_selected(TangleButton* button, gboolean selected) {
+	g_return_if_fail(button->priv->mode == TANGLE_BUTTON_SELECTABLE);
+	
+	if (button->priv->selected != selected) {
+		button->priv->selected = selected;
+		clutter_actor_queue_relayout(CLUTTER_ACTOR(button));
+		g_object_notify(G_OBJECT(button), "selected");
 	}
-	g_object_ref(action);
-	button->priv->clicked_action = action;
-	g_object_notify(G_OBJECT(button), "clicked-action");
 }
 
 static void tangle_button_handle_ancestor_event(TangleActor* actor, TangleEvent* event) {
@@ -153,14 +242,27 @@ static void tangle_button_set_property(GObject* object, guint prop_id, const GVa
 	button = TANGLE_BUTTON(object);
 
 	switch (prop_id) {
+		case PROP_BUTTON_MODE:
+			tangle_button_set_mode(button, g_value_get_enum(value));
+			break;
 		case PROP_NORMAL_BACKGROUND_ACTOR:
 			tangle_button_set_normal_background_actor(button, CLUTTER_ACTOR(g_value_get_object(value)));
 			break;
 		case PROP_INTERACTIVE_BACKGROUND_ACTOR:
 			tangle_button_set_interactive_background_actor(button, CLUTTER_ACTOR(g_value_get_object(value)));
 			break;
+		case PROP_SELECTED_BACKGROUND_ACTOR:
+			tangle_button_set_selected_background_actor(button, CLUTTER_ACTOR(g_value_get_object(value)));
+			break;
+		case PROP_SELECTED:
+			tangle_button_set_selected(button, g_value_get_boolean(value));
+			break;
 		case PROP_CLICKED_ACTION:
-			tangle_button_set_clicked_action(button, TANGLE_ACTION(g_value_get_object(value)));
+			if (button->priv->clicked_action) {
+				g_object_unref(button->priv->clicked_action);
+			}
+			button->priv->clicked_action = TANGLE_ACTION(g_value_get_object(value));
+			g_object_ref(button->priv->clicked_action);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -174,14 +276,23 @@ static void tangle_button_get_property(GObject* object, guint prop_id, GValue* v
 	button = TANGLE_BUTTON(object);
 
         switch (prop_id) {
+		case PROP_BUTTON_MODE:
+			g_value_set_enum(value, button->priv->mode);
+			break;
 		case PROP_NORMAL_BACKGROUND_ACTOR:
 			g_value_set_object(value, button->priv->normal_background_actor);
 			break;
 		case PROP_INTERACTIVE_BACKGROUND_ACTOR:
 			g_value_set_object(value, button->priv->interactive_background_actor);
 			break;
+		case PROP_SELECTED_BACKGROUND_ACTOR:
+			g_value_set_object(value, button->priv->selected_background_actor);
+			break;
+		case PROP_SELECTED:
+			g_value_set_boolean(value, button->priv->selected);
+			break;
 		case PROP_CLICKED_ACTION:
-			g_value_set_object(value, tangle_button_get_clicked_action(button));
+			g_value_set_object(value, button->priv->clicked_action);
 			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
@@ -211,6 +322,16 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 
 	button_class->clicked = tangle_button_clicked;
 
+	/**
+	 * TangleButton:selected:
+	 */
+	g_object_class_install_property(gobject_class, PROP_BUTTON_MODE,
+	                                g_param_spec_enum("button-mode",
+	                                "Button mode",
+	                                "The mode of the button",
+	                                TANGLE_TYPE_BUTTON_MODE,
+					TANGLE_BUTTON_CLICKABLE,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
 	 * TangleClutterActor:normal-background-actor:
 	 */
@@ -226,10 +347,28 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 	 */
 	g_object_class_install_property(gobject_class, PROP_INTERACTIVE_BACKGROUND_ACTOR,
 	                                g_param_spec_object("interactive-background-actor",
-	                                                    "Actor",
+	                                                    "Interactive background actor",
 	                                                    "The background actor used in interactive (interacting) state",
 	                                                    CLUTTER_TYPE_ACTOR,
 	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	/**
+	 * TangleClutterActor:selected-background-actor:
+	 */
+	g_object_class_install_property(gobject_class, PROP_SELECTED_BACKGROUND_ACTOR,
+	                                g_param_spec_object("selected-background-actor",
+	                                                    "Selected background actor",
+	                                                    "The background actor used in selected state",
+	                                                    CLUTTER_TYPE_ACTOR,
+	                                                    G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
+	/**
+	 * TangleButton:selected:
+	 */
+	g_object_class_install_property(gobject_class, PROP_SELECTED,
+	                                g_param_spec_boolean("selected",
+	                                "Selected",
+	                                "Whether the button is selected or not",
+	                                FALSE,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 	/**
 	 * TangleButton:on-clicked-action:
 	 */
@@ -257,7 +396,7 @@ static gboolean on_button_release_event(ClutterActor* actor, ClutterEvent* event
 
 static void start_interacting(TangleButton* button) {
 	TangleEvent* event;
-	
+
 	tangle_actor_set_interacting(TANGLE_ACTOR(button), TRUE);
 	if (button->priv->interactive_background_actor) {
 		tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->interactive_background_actor);
@@ -275,7 +414,9 @@ static void end_interacting(TangleButton* button) {
 	TangleEvent* event;
 	
 	tangle_actor_set_interacting(TANGLE_ACTOR(button), FALSE);
-	if (button->priv->interactive_background_actor) {
+	if (button->priv->mode == TANGLE_BUTTON_SELECTABLE && button->priv->selected && button->priv->selected_background_actor) {
+		tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->selected_background_actor);
+	} else {
 		tangle_widget_set_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
 	}
 	if (button->priv->button_release_event_handler_id) {
@@ -291,13 +432,20 @@ static void end_interacting(TangleButton* button) {
 }
 
 static gboolean on_button_release_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data) {
+	TangleButton* button;
 	gboolean handled;
 
-	end_interacting(TANGLE_BUTTON(user_data));
-	TANGLE_BUTTON(user_data)->priv->active = FALSE;;
+	button = TANGLE_BUTTON(user_data);
 
-	if (TANGLE_BUTTON(user_data)->priv->inside) {
-		g_signal_emit(user_data, signals[CLICKED], 0, &handled);
+	if (button->priv->inside && button->priv->mode == TANGLE_BUTTON_SELECTABLE) {
+		button->priv->selected = !button->priv->selected;
+	}
+
+	end_interacting(button);
+	button->priv->active = FALSE;;
+
+	if (button->priv->inside) {
+		g_signal_emit(button, signals[CLICKED], 0, &handled);
 	}
 
 	return FALSE;
