@@ -44,6 +44,7 @@ struct _TangleDraggableActorPrivate {
 	gulong captured_event_handler_id;
 	guint dragging_effective : 1;
 	guint descendant_interacting : 1;
+	guint descendant_dragging : 1;
 	guint use_anchor_point : 1;
 };
 
@@ -213,9 +214,13 @@ static void tangle_draggable_actor_handle_descendant_event(TangleActor* actor, T
 		switch (event->type) {
 			case TANGLE_EVENT_INTERACTION_BEGAN:
 				draggable_actor->priv->descendant_interacting = TRUE;
+				if (event->interaction.dragging) {
+					draggable_actor->priv->descendant_dragging = TRUE;
+				}
 				break;
 			case TANGLE_EVENT_INTERACTION_ENDED:
 				draggable_actor->priv->descendant_interacting = FALSE;
+				draggable_actor->priv->descendant_dragging = FALSE;
 				break;
 			default:
 				break;
@@ -390,6 +395,9 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 
 		if (draggable_actor->priv->dragging_effective) {
 			handle_droppable_actor(draggable_actor->priv->dragging);
+			if (event->type == CLUTTER_BUTTON_RELEASE) {
+				send_interaction_event(TANGLE_ACTOR(draggable_actor), FALSE);
+			}
 			g_signal_emit(draggable_actor, signals[(event->type == CLUTTER_MOTION ? DO_DRAGGING : END_DRAGGING)], 0, draggable_actor->priv->dragging, &handled);
 			if (event->type == CLUTTER_BUTTON_RELEASE) {
 				if (draggable_actor->priv->dragging->droppable_actor) {
@@ -398,12 +406,12 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 				tangle_dragging_free(draggable_actor->priv->dragging);
 				draggable_actor->priv->dragging = NULL;
 				g_signal_handler_disconnect(actor, draggable_actor->priv->captured_event_handler_id);
-				send_interaction_event(TANGLE_ACTOR(draggable_actor), FALSE);
 			}
 		} else {
-			if (event->type == CLUTTER_MOTION && !draggable_actor->priv->descendant_interacting ||
-			    ABS_F(draggable_actor->priv->dragging->dy) > draggable_actor->priv->dragging_threshold_x ||
-			    ABS_F(draggable_actor->priv->dragging->dx) > draggable_actor->priv->dragging_threshold_y) {
+			if (event->type == CLUTTER_MOTION && !draggable_actor->priv->descendant_dragging &&
+			    (!draggable_actor->priv->descendant_interacting ||
+			     ABS_F(draggable_actor->priv->dragging->dy) > draggable_actor->priv->dragging_threshold_x ||
+			     ABS_F(draggable_actor->priv->dragging->dx) > draggable_actor->priv->dragging_threshold_y)) {
 				draggable_actor->priv->dragging_effective = TRUE;
 				handle_droppable_actor(draggable_actor->priv->dragging);
 				g_signal_emit(draggable_actor, signals[BEGIN_DRAGGING], 0, draggable_actor->priv->dragging, &handled);	
@@ -474,11 +482,12 @@ static void handle_droppable_actor(TangleDragging* dragging) {
 
 static void send_interaction_event(TangleActor* actor, gboolean began) {
 	TangleEvent* event;
-	
+
 	event = tangle_event_new((began ? TANGLE_EVENT_INTERACTION_BEGAN : TANGLE_EVENT_INTERACTION_ENDED),
 	                         TANGLE_ACTOR(actor));
 	event->interaction.x_axis = TRUE;
 	event->interaction.y_axis = TRUE;
+	event->interaction.dragging = TRUE;
 	tangle_actor_send_event(actor, event);
 	tangle_event_free(event);
 }
