@@ -20,6 +20,7 @@ G_DEFINE_TYPE(TangleDroppableActor, tangle_droppable_actor, TANGLE_TYPE_WRAPPER_
 
 enum {
 	PROP_0,
+	PROP_DROPPING_ENABLED
 };
 
 enum {
@@ -30,7 +31,9 @@ enum {
 
 struct _TangleDroppableActorPrivate {
 	ClutterColor hilight_color;
+
 	guint hilighted : 1;
+	guint dropping_enabled : 1;
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
@@ -42,7 +45,7 @@ ClutterActor* tangle_droppable_actor_new(ClutterActor* wrapped) {
 
 gboolean tangle_droppable_actor_is_dragging_droppable(TangleDroppableActor* droppable_actor, TangleDragging* dragging) {
 
-	return TANGLE_DROPPABLE_ACTOR_GET_CLASS(droppable_actor)->is_dragging_droppable(droppable_actor, dragging);
+	return droppable_actor->priv->dropping_enabled && TANGLE_DROPPABLE_ACTOR_GET_CLASS(droppable_actor)->is_dragging_droppable(droppable_actor, dragging);
 }
 
 void tangle_droppable_actor_handle_dragging(TangleDroppableActor* droppable_actor, TangleDragging* dragging) {
@@ -117,6 +120,9 @@ static void tangle_droppable_actor_set_property(GObject* object, guint prop_id,
 	droppable_actor = TANGLE_DROPPABLE_ACTOR(object);
 
 	switch (prop_id) {
+		case PROP_DROPPING_ENABLED:
+			droppable_actor->priv->dropping_enabled = g_value_get_boolean(value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -129,6 +135,9 @@ static void tangle_droppable_actor_get_property(GObject* object, guint prop_id,
 	droppable_actor = TANGLE_DROPPABLE_ACTOR(object);
 
         switch (prop_id) {
+		case PROP_DROPPING_ENABLED:
+			g_value_set_boolean(value, droppable_actor->priv->dropping_enabled);
+			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -158,6 +167,18 @@ static void tangle_droppable_actor_class_init(TangleDroppableActorClass* droppab
 	droppable_actor_class->handle_dragging = tangle_droppable_actor_real_handle_dragging;
 	droppable_actor_class->handle_dropping = tangle_droppable_actor_real_handle_dropping;
 
+	/**
+	 * TangleDroppableActor:dropping-enabled:
+	 *
+	 * Whether the dropping actor accepts draggable actors or not.
+	 */
+	g_object_class_install_property(gobject_class, PROP_DROPPING_ENABLED,
+	                                g_param_spec_boolean("dropping-enabled",
+	                                "Dropping enabled",
+	                                "Whether the dropping actor accepts draggable actors or not",
+	                                TRUE,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+
 	/**
 	 * TangleDroppableActor::handle-dragging:
 	 * @actor: the object which received the signal
@@ -188,6 +209,8 @@ static void tangle_droppable_actor_class_init(TangleDroppableActorClass* droppab
 static void tangle_droppable_actor_init(TangleDroppableActor* droppable_actor) {
 	droppable_actor->priv = G_TYPE_INSTANCE_GET_PRIVATE(droppable_actor, TANGLE_TYPE_DROPPABLE_ACTOR, TangleDroppableActorPrivate);
 
+	droppable_actor->priv->dropping_enabled = TRUE;
+
 droppable_actor->priv->hilight_color.red = 255;
 droppable_actor->priv->hilight_color.green = 255;
 droppable_actor->priv->hilight_color.blue = 255;
