@@ -48,6 +48,7 @@ struct _TangleScrollingActorPrivate {
 	gulong captured_event_handler_id;
 
 	guint descendant_interacting : 1;	
+	guint descendant_dragging : 1;
 	guint scrolling_effective : 1;
 };
 
@@ -183,9 +184,13 @@ static void tangle_scrolling_actor_handle_descendant_event(TangleActor* actor, T
 		switch (event->type) {
 			case TANGLE_EVENT_INTERACTION_BEGAN:
 				scrolling_actor->priv->descendant_interacting = TRUE;
+				if (event->interaction.dragging) {
+					scrolling_actor->priv->descendant_dragging = TRUE;
+				}
 				break;
 			case TANGLE_EVENT_INTERACTION_ENDED:
 				scrolling_actor->priv->descendant_interacting = FALSE;
+				scrolling_actor->priv->descendant_dragging = FALSE;
 				break;
 			default:
 				break;
@@ -374,9 +379,10 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 				send_interaction_event(TANGLE_ACTOR(scrolling_actor), FALSE);
 			}
 		} else {
-			if (event->type == CLUTTER_MOTION && !scrolling_actor->priv->descendant_interacting ||
-			    ABS_F(dy) > scrolling_actor->priv->scrolling_threshold_x ||
-			    ABS_F(dx) > scrolling_actor->priv->scrolling_threshold_y) {
+			if (event->type == CLUTTER_MOTION && !scrolling_actor->priv->descendant_dragging &&
+			    (!scrolling_actor->priv->descendant_interacting ||
+			     ABS_F(dy) > scrolling_actor->priv->scrolling_threshold_x ||
+			     ABS_F(dx) > scrolling_actor->priv->scrolling_threshold_y)) {
 				scrolling_actor->priv->scrolling_effective = TRUE;
 				send_interaction_event(TANGLE_ACTOR(scrolling_actor), TRUE);
 			} else if (event->type == CLUTTER_BUTTON_RELEASE) {
@@ -397,6 +403,7 @@ static void send_interaction_event(TangleActor* actor, gboolean began) {
 	                         TANGLE_ACTOR(actor));
 	event->interaction.x_axis = TRUE;
 	event->interaction.y_axis = TRUE;
+	event->interaction.dragging = TRUE;
 	tangle_actor_send_event(actor, event);
 	tangle_event_free(event);
 }
