@@ -38,8 +38,8 @@ struct _TangleStylesheetPrivate {
 	GList* compound_styles;
 };
 
-guint signals[LAST_SIGNAL];
-static TangleStylesheet* default_stylesheet;
+static guint signals[LAST_SIGNAL] = { 0 };
+static TangleStylesheet* default_stylesheet = NULL;
 
 static TangleStylesheet* load_from_file(const gchar* directory_prefix, const gchar* name);
 
@@ -140,7 +140,11 @@ TangleStyle* tangle_stylesheet_get_style_for_object(TangleStylesheet* stylesheet
 }
 
 TangleStylesheet* tangle_stylesheet_get_default() {
-
+	
+	if (!default_stylesheet) {
+		default_stylesheet = tangle_stylesheet_new_from_file("draft");
+	}
+	
 	return default_stylesheet;
 }
 
